pub trait SessionStore<T>:
'static
+ Send
+ Sync
+ SessionStoreImpl<T> { }Expand description
Backing storage for session data.
This trait is sealed and intended to be opaque. The details of this trait are open to change across non-major version bumps; as such, depending on them may cause breakage.